cowsay

package
v0.0.0-...-efe05a5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 16, 2024 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Cow = ` 
         \  ^__^
          \ (oo)\_______
            (__)\       )\/\
                ||----w |
                ||     ||
`

Functions

func BuildBalloon

func BuildBalloon(fortune string) string

Builds a text balloon for the fortune, ensuring proper alignment and padding.

fortune: The text of the fortune to be placed in the balloon.

Types

This section is empty.

Jump to