Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Cow = `
\ ^__^
\ (oo)\_______
(__)\ )\/\
||----w |
|| ||
`
Functions ¶
func BuildBalloon ¶
Builds a text balloon for the fortune, ensuring proper alignment and padding.
fortune: The text of the fortune to be placed in the balloon.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.